==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeAPIServerListBuilder extends io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListBuilder>{
  public KubeAPIServerListBuilder() {
    this(false);
  }
  public KubeAPIServerListBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeAPIServerList(), validationEnabled);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeAPIServerList(), validationEnabled);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance) {
    this(fluent, instance, false);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance) {
    this(instance,false);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList build() {
    KubeAPIServerList buildable = new KubeAPIServerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeAPIServerListBuilder that = (KubeAPIServerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeAPIServerListBuilder extends io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListBuilder>{
  public KubeAPIServerListBuilder() {
    this(false);
  }
  public KubeAPIServerListBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeAPIServerList(), validationEnabled);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeAPIServerList(), validationEnabled);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance) {
    this(fluent, instance, false);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance) {
    this(instance,false);
  }
  public KubeAPIServerListBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.KubeAPIServerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList build() {
    KubeAPIServerList buildable = new KubeAPIServerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeAPIServerListBuilder that = (KubeAPIServerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
